@@ -35,7 +35,7 @@
 #include "SDL_atomic.h"
 #include "SDL_mutex.h"
 
-#if (defined(__WIN32__) || defined(__GDK__)) && !defined(__WINRT__) && !defined(HAVE_LIBC)
+#if (defined(__WIN32__) || defined(__GDK__)) && !defined(__WINRT__)
 #include <process.h> /* _beginthreadex() and _endthreadex() */
 #endif
 #if defined(__OS2__) /* for _beginthread() and _endthread() */
@@ -90,7 +90,7 @@ typedef enum SDL_ThreadPriority {
 typedef int (SDLCALL * SDL_ThreadFunction) (void *data);
 
 
-#if (defined(__WIN32__) || defined(__GDK__)) && !defined(__WINRT__) && !defined(HAVE_LIBC)
+#if (defined(__WIN32__) || defined(__GDK__)) && !defined(__WINRT__) && !defined(__CYGWIN__)
 /**
  *  \file SDL_thread.h
  *
